pm4py.streaming.algo.conformance package
========================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.streaming.algo.conformance.footprints
   pm4py.streaming.algo.conformance.tbr
   pm4py.streaming.algo.conformance.temporal

Module contents
---------------

.. automodule:: pm4py.streaming.algo.conformance
   :members:
   :undoc-members:
   :show-inheritance:
